diff lisp/international/characters.el @ 23527:06e8c3b9deec

Setup charset property nospace-between-words.
author Kenichi Handa <handa@m17n.org>
date Wed, 21 Oct 1998 11:50:56 +0000
parents d82b305ac37b
children 6964e11724dc
line wrap: on
line diff
--- a/lisp/international/characters.el	Wed Oct 21 11:50:56 1998 +0000
+++ b/lisp/international/characters.el	Wed Oct 21 11:50:56 1998 +0000
@@ -626,13 +626,15 @@
     (setq l (cdr l))))
 
 
 ;; Setup auto-fill-chars for characters that should invoke auto-filling.
 ;; SPACE and NEWLIE are already set.
 (let ((l '(katakana-jisx0201
 	   japanese-jisx0208 japanese-jisx0212
 	   chinese-gb2312 chinese-big5-1 chinese-big5-2)))
   (while l
     (aset auto-fill-chars (make-char (car l)) t)
+    (put-charset-property (car l) 'nospace-between-words t)
     (setq l (cdr l))))
 
 ;;; Local Variables:
@@ -626,13 +626,15 @@
 
 
-;; Setup auto-fill-chars for characters that should invoke auto-filling.
-;; SPACE and NEWLIE are already set.
+;; Setup auto-fill-chars for charsets that should invoke auto-filling.
+;; SPACE and NEWLIE are already set.  Also put `nospace-between-words'
+;; property to the charsets.
 (let ((l '(katakana-jisx0201
 	   japanese-jisx0208 japanese-jisx0212